@@ -1,4 +1,4 @@
-// Copyright (c) 2018 Dr. Colin Hirsch and Daniel Frey
+// Copyright (c) 2018-2019 Dr. Colin Hirsch and Daniel Frey
 // Please see LICENSE for license or visit https://github.com/taocpp/PEGTL/
 
 #include <algorithm>
@@ -310,7 +310,7 @@ namespace tao
          struct selector
             : parse_tree::selector<
                  Rule,
-                 parse_tree::apply_store_content::to<
+                 parse_tree::store_content::on<
                     grammar::rulename,
                     grammar::prose_val,
                     grammar::hex_val::value,
@@ -324,12 +324,12 @@ namespace tao
                     grammar::bin_val::type,
                     grammar::repeat,
                     grammar::defined_as_op >,
-                 parse_tree::apply_remove_content::to<
+                 parse_tree::remove_content::on<
                     grammar::option,
                     grammar::and_predicate,
                     grammar::not_predicate,
                     grammar::rule >,
-                 parse_tree::apply_fold_one::to<
+                 parse_tree::fold_one::on<
                     grammar::alternation,
                     grammar::group,
                     grammar::repetition,
@@ -340,7 +340,8 @@ namespace tao
          template<>
          struct selector< grammar::quoted_string > : std::true_type
          {
-            static void transform( node_ptr& n )
+            template< typename... States >
+            static void transform( node_ptr& n, States&&... /*unused*/ )
             {
                shift( n->m_begin, 1 );
                shift( n->m_end, -1 );
@@ -348,15 +349,15 @@ namespace tao
                const std::string content = n->content();
                for( const auto c : content ) {
                   if( std::isalpha( c ) != 0 ) {
-                     n->id = &typeid( istring_tag );
+                     n->id = typeid( istring_tag );
                      return;
                   }
                }
                if( content.size() == 1 ) {
-                  n->id = &typeid( one_tag );
+                  n->id = typeid( one_tag );
                }
                else {
-                  n->id = &typeid( string_tag );
+                  n->id = typeid( string_tag );
                }
             }
          };
@@ -364,14 +365,15 @@ namespace tao
          template<>
          struct selector< grammar::case_sensitive_string > : std::true_type
          {
-            static void transform( node_ptr& n )
+            template< typename... States >
+            static void transform( node_ptr& n, States&&... /*unused*/ )
             {
                n = std::move( n->children.back() );
                if( n->content().size() == 1 ) {
-                  n->id = &typeid( one_tag );
+                  n->id = typeid( one_tag );
                }
                else {
-                  n->id = &typeid( string_tag );
+                  n->id = typeid( string_tag );
                }
             }
          };
@@ -443,7 +445,8 @@ namespace tao
          template<>
          struct selector< grammar::rule > : std::true_type
          {
-            static void transform( node_ptr& n )
+            template< typename... States >
+            static void transform( node_ptr& n, States&&... /*unused*/ )
             {
                const auto rname = get_rulename( n->children.front() );
                assert( n->children.at( 1 )->is< grammar::defined_as_op >() );
@@ -465,7 +468,7 @@ namespace tao
                   // if the previous rule does not assign an alternation, create an intermediate alternation and move its assignee into it.
                   if( !previous->is< abnf::grammar::alternation >() ) {
                      node_ptr s( new parse_tree::node );
-                     s->id = &typeid( abnf::grammar::alternation );
+                     s->id = typeid( abnf::grammar::alternation );
                      s->source = previous->source;
                      s->m_begin = previous->m_begin;
                      s->m_end = previous->m_end;
@@ -499,12 +502,12 @@ namespace tao
             using function_t = std::string ( * )( const node_ptr& n );
             function_t default_ = nullptr;
 
-            std::map< const std::type_info*, function_t > map_;
+            std::map< std::type_index, function_t > map_;
 
             template< typename T >
             void add( const function_t& f )
             {
-               map_.insert( { &typeid( T ), f } );
+               map_.insert( { typeid( T ), f } );
             }
 
             std::string operator()( const node_ptr& n ) const
@@ -708,7 +711,7 @@ int main( int argc, char** argv )
    catch( const parse_error& e ) {
       const auto p = e.positions.front();
       std::cerr << e.what() << std::endl
-                << in.line_as_string( p ) << std::endl
+                << in.line_at( p ) << std::endl
                 << std::string( p.byte_in_line, ' ' ) << '^' << std::endl;
    }
 
